@@ -22,14 +22,19 @@ struct sockaddr;
         v8::String::NewFromUtf8(isolate, constant);                           \
     v8::PropertyAttribute constant_attributes =                               \
         static_cast<v8::PropertyAttribute>(v8::ReadOnly | v8::DontDelete);    \
-    target->ForceSet(isolate->GetCurrentContext(),                            \
-                     constant_name,                                           \
-                     constant_value,                                          \
-                     constant_attributes);                                    \
+    target->DefineOwnProperty(isolate->GetCurrentContext(),                   \
+                              constant_name,                                  \
+                              constant_value,                                 \
+                              constant_attributes).FromJust();                \
   } while (0)
 
 namespace node {
 
+// Set in node.cc by ParseArgs when --preserve-symlinks is used.
+// Used in node_config.cc to set a constant on process.binding('config')
+// that is used by lib/module.js
+extern bool config_preserve_symlinks;
+
 // Forward declaration
 class Environment;
 
@@ -126,6 +131,8 @@ constexpr size_t arraysize(const T(&)[N]) { return N; }
 # define NO_RETURN
 #endif
 
+bool IsExceptionDecorated(Environment* env, v8::Local<v8::Value> er);
+
 void AppendExceptionLine(Environment* env,
                          v8::Local<v8::Value> er,
                          v8::Local<v8::Message> message);
@@ -191,38 +198,6 @@ void ThrowUVException(v8::Isolate* isolate,
                       const char* path = nullptr,
                       const char* dest = nullptr);
 
-NODE_DEPRECATED("Use ThrowError(isolate)",
-                inline void ThrowError(const char* errmsg) {
-  v8::Isolate* isolate = v8::Isolate::GetCurrent();
-  return ThrowError(isolate, errmsg);
-})
-NODE_DEPRECATED("Use ThrowTypeError(isolate)",
-                inline void ThrowTypeError(const char* errmsg) {
-  v8::Isolate* isolate = v8::Isolate::GetCurrent();
-  return ThrowTypeError(isolate, errmsg);
-})
-NODE_DEPRECATED("Use ThrowRangeError(isolate)",
-                inline void ThrowRangeError(const char* errmsg) {
-  v8::Isolate* isolate = v8::Isolate::GetCurrent();
-  return ThrowRangeError(isolate, errmsg);
-})
-NODE_DEPRECATED("Use ThrowErrnoException(isolate)",
-                inline void ThrowErrnoException(int errorno,
-                                                const char* syscall = nullptr,
-                                                const char* message = nullptr,
-                                                const char* path = nullptr) {
-  v8::Isolate* isolate = v8::Isolate::GetCurrent();
-  return ThrowErrnoException(isolate, errorno, syscall, message, path);
-})
-NODE_DEPRECATED("Use ThrowUVException(isolate)",
-                inline void ThrowUVException(int errorno,
-                                             const char* syscall = nullptr,
-                                             const char* message = nullptr,
-                                             const char* path = nullptr) {
-  v8::Isolate* isolate = v8::Isolate::GetCurrent();
-  return ThrowUVException(isolate, errorno, syscall, message, path);
-})
-
 class ArrayBufferAllocator : public v8::ArrayBuffer::Allocator {
  public:
   ArrayBufferAllocator() : env_(nullptr) { }
